==> blesta-5.10.2.zip: blesta/core/Automation/Tasks/Task/language/uk_ua/cleanup_logs.php <==
<?php
/**
 * Cleanup Logs
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Automation.task.cleanup_logs.logs_cron_deleted'] = 'Видалено старі журнали Cron %1$.';
$lang['Automation.task.cleanup_logs.logs_transaction_deleted'] = 'Видалено старі журнали транзакцій %1$.';
$lang['Automation.task.cleanup_logs.logs_service_deleted'] = 'Видалено старі журнали служби %1$.';
$lang['Automation.task.cleanup_logs.logs_client_settings_deleted'] = 'Видалено старі журнали налаштувань клієнта %1$.';
$lang['Automation.task.cleanup_logs.logs_user_deleted'] = 'Видалено старі журнали користувачів %1$.';
$lang['Automation.task.cleanup_logs.logs_messenger_deleted'] = 'Видалено старі журнали Messenger %1$.';
$lang['Automation.task.cleanup_logs.logs_email_deleted'] = 'Видалено старі журнали електронної пошти %1$.';
$lang['Automation.task.cleanup_logs.logs_contact_deleted'] = 'Видалено старі журнали контактів %1$.';
$lang['Automation.task.cleanup_logs.logs_accountaccess_deleted'] = 'Видалено старі журнали доступу до облікового запису %1$.';
$lang['Automation.task.cleanup_logs.logs_module_deleted'] = 'Видалено старі журнали модуля %1$.';
$lang['Automation.task.cleanup_logs.logs_gateway_deleted'] = 'Видалено старі журнали шлюзу %1$.';
$lang['Automation.task.cleanup_logs.completed'] = 'Завдання очищення журналів завершено.';
$lang['Automation.task.cleanup_logs.attempt'] = 'Спроба почистити старі колоди.';

==> blesta-5.11.4.zip: blesta/core/Automation/Tasks/Task/language/uk_ua/cleanup_logs.php <==
<?php
/**
 * Cleanup Logs
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Automation.task.cleanup_logs.logs_cron_deleted'] = 'Видалено старі журнали Cron %1$.';
$lang['Automation.task.cleanup_logs.logs_transaction_deleted'] = 'Видалено старі журнали транзакцій %1$.';
$lang['Automation.task.cleanup_logs.logs_service_deleted'] = 'Видалено старі журнали служби %1$.';
$lang['Automation.task.cleanup_logs.logs_client_settings_deleted'] = 'Видалено старі журнали налаштувань клієнта %1$.';
$lang['Automation.task.cleanup_logs.logs_user_deleted'] = 'Видалено старі журнали користувачів %1$.';
$lang['Automation.task.cleanup_logs.logs_messenger_deleted'] = 'Видалено старі журнали Messenger %1$.';
$lang['Automation.task.cleanup_logs.logs_email_deleted'] = 'Видалено старі журнали електронної пошти %1$.';
$lang['Automation.task.cleanup_logs.logs_contact_deleted'] = 'Видалено старі журнали контактів %1$.';
$lang['Automation.task.cleanup_logs.logs_accountaccess_deleted'] = 'Видалено старі журнали доступу до облікового запису %1$.';
$lang['Automation.task.cleanup_logs.logs_module_deleted'] = 'Видалено старі журнали модуля %1$.';
$lang['Automation.task.cleanup_logs.logs_gateway_deleted'] = 'Видалено старі журнали шлюзу %1$.';
$lang['Automation.task.cleanup_logs.completed'] = 'Завдання очищення журналів завершено.';
$lang['Automation.task.cleanup_logs.attempt'] = 'Спроба почистити старі колоди.';
$lang['Automation.task.cleanup_logs.logs_service_changes_deleted'] = '%1$s видалено старі журнали змін служби.';
